import Grid from "@mui/material/Grid";
import Box from "@mui/material/Box";
import Typography from "@mui/material/Typography";
import SessionsChart from "../SessionsChart/sessionChart";
import StatCard, { StatCardProps } from "../StatCard/statCard";
import ResourcesPieChart from "../ResourcePieChart/resourcePieChart";
import RoundedBarChart from "../barChartCard/barChartCard";
import LineChartCard from "../LineChartCard/lineChartCard";

const data: StatCardProps[] = [
  { title: "Total Charge Stations", value: "86" },
  { title: "Charging Completed", value: "12" },
  { title: "Active Users", value: "24" },
  { title: "Total Energy Consumed", value: "08" },
];

export default function MainGrid() {
  return (
    <Box sx={{ width: "100%", maxWidth: "1600px", mx: "auto", px: { xs: 2, sm: 1, md: 0 } }}>
      {/* Dashboard Header */}
      <Typography component="h2" variant="h6" sx={{ mb: 2 }}>
        Dashboard
      </Typography>

      {/* Grid Layout */}
      <Grid container spacing={3} columns={12}>
        {/* Statistic Cards */}
        {data.map((card, index) => (
          <Grid key={index} item xs={12} sm={6} md={3} lg={3}>
            <StatCard {...card} />
          </Grid>
        ))}

        {/* Charts */}
        <Grid item xs={12} sm={12} md={6} lg={6}>
          <SessionsChart />
        </Grid>
        <Grid item xs={12} sm={12} md={6} lg={6}>
          <ResourcesPieChart />
        </Grid>
        <Grid item xs={12} sm={12} md={6} lg={6}>
          <RoundedBarChart />
        </Grid>
        <Grid item xs={12} sm={12} md={6} lg={6}>
          <LineChartCard />
        </Grid>
      </Grid>
    </Box>
  );
}
